aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorpete <pete@36083f99-b078-4883-b0ff-0f9b5a30f544>2008-06-24 11:12:19 +0000
committerpete <pete@36083f99-b078-4883-b0ff-0f9b5a30f544>2008-06-24 11:12:19 +0000
commit118e59fa7a8980356cd326bef558afb7902af1be (patch)
treec8f402e8e34d0587683cf81be5694477e0d84276
parent1d067acf070549c4edcb662252edd03907b1d9a3 (diff)
downloadelgg-118e59fa7a8980356cd326bef558afb7902af1be.tar.gz
elgg-118e59fa7a8980356cd326bef558afb7902af1be.tar.bz2
updated profile box
git-svn-id: https://code.elgg.org/elgg/trunk@1093 36083f99-b078-4883-b0ff-0f9b5a30f544
-rw-r--r--mod/profile/views/default/profile/css.php6
-rw-r--r--mod/profile/views/default/profile/userdetails.php31
-rw-r--r--mod/profile/views/default/user/user.php2
-rw-r--r--views/default/canvas/layouts/narrow_right_sidebar.php2
-rw-r--r--views/default/canvas/layouts/two_column.php2
-rw-r--r--views/default/canvas/layouts/widgets.php2
-rw-r--r--views/default/css.php52
-rw-r--r--views/default/pageshells/pageshell.php7
8 files changed, 84 insertions, 20 deletions
diff --git a/mod/profile/views/default/profile/css.php b/mod/profile/views/default/profile/css.php
index 3b4bd031d..655e072ad 100644
--- a/mod/profile/views/default/profile/css.php
+++ b/mod/profile/views/default/profile/css.php
@@ -2,6 +2,8 @@
?>
+/*
+
#user_menu {
position:absolute;
border:1px solid #333333;
@@ -34,4 +36,6 @@
background-color: #336699;
color: #fff;
text-decoration: none;
-} \ No newline at end of file
+}
+
+*/ \ No newline at end of file
diff --git a/mod/profile/views/default/user/user.php b/mod/profile/views/default/user/user.php
index 4a8b9ee0b..0b808769a 100644
--- a/mod/profile/views/default/user/user.php
+++ b/mod/profile/views/default/user/user.php
@@ -12,6 +12,6 @@
* @uses $vars['entity'] The user entity
*/
- echo elgg_view_layout("one_column",elgg_view("profile/userdetails",$vars));
+ echo elgg_view("profile/userdetails",$vars);
?> \ No newline at end of file
diff --git a/views/default/canvas/layouts/narrow_right_sidebar.php b/views/default/canvas/layouts/narrow_right_sidebar.php
index d2b109dd8..abb1ca733 100644
--- a/views/default/canvas/layouts/narrow_right_sidebar.php
+++ b/views/default/canvas/layouts/narrow_right_sidebar.php
@@ -32,7 +32,7 @@
</div><!-- /#wrapper_maincontent -->
<p></p><!-- necessary to avoid an ie7 bug? -->
-</div><!-- /#layout_maincontent -->
+</div><!-- /#layout_maincontent .has_narrow_sidebar_right -->
<!-- This clearing element should immediately follow the #layout_maincontent to force the #container to contain all child floats -->
<div class="clearfloat"></div> \ No newline at end of file
diff --git a/views/default/canvas/layouts/two_column.php b/views/default/canvas/layouts/two_column.php
index ccc2fee6a..a8b607f1f 100644
--- a/views/default/canvas/layouts/two_column.php
+++ b/views/default/canvas/layouts/two_column.php
@@ -32,7 +32,7 @@
</div><!-- /#wrapper_maincontent -->
<p></p><!-- necessary to avoid an ie7 bug? -->
-</div><!-- /#layout_maincontent -->
+</div><!-- /#layout_maincontent .has_sidebar_right -->
<!-- This clearing element should immediately follow the #layout_maincontent to force the #container to contain all child floats -->
<div class="clearfloat"></div> \ No newline at end of file
diff --git a/views/default/canvas/layouts/widgets.php b/views/default/canvas/layouts/widgets.php
index 1ef87d2f6..dcc969b9e 100644
--- a/views/default/canvas/layouts/widgets.php
+++ b/views/default/canvas/layouts/widgets.php
@@ -201,7 +201,7 @@
</div><!-- /#wrapper_maincontent -->
<p></p><!-- necessary to avoid an ie7 bug? -->
-</div><!-- /#layout_maincontent -->
+</div><!-- /#layout_maincontent .has_sidebar_right -->
<!-- This clearing element should immediately follow the #layout_maincontent to force the #container to contain all child floats -->
<div class="clearfloat"></div> \ No newline at end of file
diff --git a/views/default/css.php b/views/default/css.php
index 4bdb24256..a8b33085d 100644
--- a/views/default/css.php
+++ b/views/default/css.php
@@ -714,8 +714,52 @@ input[type="submit"] {
margin:0;
}
-.page_title {
- padding:0px 10px 20px 20px;
+/* ***************************************
+ PROFILE
+*************************************** */
+#profile_info {
+ margin:0 0 20px 0;
+ border-bottom:1px solid #cccccc;
+}
+#profile_menu_wrapper p {
+ border-bottom:1px solid #cccccc;
+ padding:0 0 0 3px;
+}
+#profile_menu_wrapper p:first-child {
+ border-top:1px solid #cccccc;
+}
+#profile_menu_wrapper p:hover {
+ background:#4690d6;
+}
+#profile_menu_wrapper a:hover {
+ color:#ffffff;
+ text-decoration:none;
+}
+p.user_menu_friends {
+ margin:0;
+}
+#profile_info_column_left {
+ float:left;
+ width:200px;
+ margin: 0 20px 0 0;
+}
+#profile_info_column_right {
+ float:left;
+ width:305px;
+}
+#profile_info_column_left img {
+ padding:0 0 20px 0;
+}
+#profile_info_column_right p {
+ margin:7px 0 7px 0;
+ line-height:1.3em;
+}
+#profile_info_wide p {
+ margin:7px 0 7px 0;
+ line-height:1.4em;
+}
+#profile_info_wide .profile_info_edit_buttons {
+ margin:0;
}
@@ -747,7 +791,9 @@ input[type="submit"] {
END
*************************************** */
-
+.page_title {
+ padding:0px 10px 20px 20px;
+}
diff --git a/views/default/pageshells/pageshell.php b/views/default/pageshells/pageshell.php
index 6d81d134a..e8e262e95 100644
--- a/views/default/pageshells/pageshell.php
+++ b/views/default/pageshells/pageshell.php
@@ -58,8 +58,11 @@
<!-- canvas -->
-<div id="layout_canvas">
-<h2 class="page_title"><?php echo $vars['title']; ?></h2>
+<div id="layout_canvas">
+
+<!-- temporarily disabled page headers -->
+<!-- <h2 class="page_title"><?php echo $vars['title']; ?></h2> -->
+
<?php echo $vars['body']; ?>
<div class="clearfloat"></div>
</div><!-- /#layout_canvas -->
diff --git a/mod/profile/views/default/profile/userdetails.php b/mod/profile/views/default/profile/userdetails.php
index bee3598b2..30de55189 100644
--- a/mod/profile/views/default/profile/userdetails.php
+++ b/mod/profile/views/default/profile/userdetails.php
@@ -18,11 +18,11 @@
$iconsize = "medium";
}
- //wrap the icon and links in a div
- echo "<div style=\"float:left;width:200px;\">";
+ // wrap all profile info
+ echo "<div id=\"profile_info\">";
- // display the users name
- // echo "<h2><a href=\"" . $vars['entity']->getUrl() . "\">" . $vars['entity']->name . "</a></h2>";
+ // wrap the icon and links in a div
+ echo "<div id=\"profile_info_column_left\">";
// get the user's main profile picture
echo elgg_view(
@@ -34,16 +34,19 @@
);
//display relevant links
- echo "<div style=\"clear:both\">" . elgg_view("profile/profilelinks", array("entity" => $vars['entity'])) . "</div>";
+ echo "<div style=\"clear:both\"></div>" . elgg_view("profile/profilelinks", array("entity" => $vars['entity']));
- //close the icon and links div
+ // close the icon and links div
echo "</div>";
?>
- <div style="margin:0 0 0 210px; width:300px;" >
+ <div id="profile_info_column_right" >
<?php
+
+ // display the users name
+ echo "<h2><a href=\"" . $vars['entity']->getUrl() . "\">" . $vars['entity']->name . "</a></h2> <br />";
if ($vars['full'] == true) {
@@ -80,7 +83,11 @@
}
?>
- </div>
+ </div><!-- /#profile_info_column_right -->
+
+ <div style="clearfloat"></div>
+
+ <div id="profile_info_wide">
<p><b><?php echo elgg_echo("profile:aboutme"); ?></b><br /><?php echo nl2br($vars['entity']->description); ?></p>
<?php
@@ -88,7 +95,7 @@
if ($vars['entity']->canEdit()) {
?>
- <p>
+ <p class="profile_info_edit_buttons">
<a href="<?php echo $vars['url']; ?>mod/profile/edit.php"><?php echo elgg_echo("edit"); ?></a>
</p>
<?php
@@ -108,4 +115,8 @@
<?php
}
}
-?> \ No newline at end of file
+?>
+
+</div><!-- /#profile_info_wide -->
+
+</div><!-- /#profile_info -->